# GENFIRE
GENeralized Fourier Iterative REconstruction (GENFIRE) is a python package for 3D reconstruction from arbitrarily oriented projection images
## Documentation
The full documentation for installing/using GENFIRE is the website in ./documentation/ and can be viewed by opening ./documentation/index.html in a web browser
